package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````8)P$"#0```"PPP```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(U+,`
M`-2S```%`````!````$```#DO@``Y$X%".1.!0AT`@``P!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2^``#D3@4(Y$X%"!P!```<`0``!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M80```',````+``````````````!#`````````$@```!'``````````````!:
M````/@```#D```!+````!````%@`````````,0```%\```!5````:@```&P`
M``!G````!0```"P``````````````"H```!C````1@``````````````9```
M`$D```!E````"0````````!2````<@````(```!-`````````!\`````````
M<`````````!1````;@``````````````9@```"@```!/````.@``````````
M````;P```#4```!`````10``````````````$P`````````_````````````
M```C`````````!P````P````#````#(````I````5```````````````6P``
M`%`````\````7@```$P````[````-``````````-````````````````````
M5@```&T`````````1````%T```!"````/0```"<````!````````````````
M`````````````````````````````````````````````````````````$X`
M``````````````````````````````\`````````$````!4```!@````````
M````````````%```````````````$@`````````9````````````````````
M`````%D`````````5P````````!H```````````````1````````````````
M````&P`````````F````:0```"0````(`````````"\````E````#@```!T`
M````````80```"$`````````&@````H``````````````$$`````````,P``
M`!X````N`````````'$```!<`````````$H````'``````````````!K````
M````````````````````````````````(@``````````````&``````````V
M`````````"L`````````````````````````%P`````````6`````````%,`
M````````!@```````````````````&(````W`````P```"`````M````.```
M`"4```!.````"`````@`````$!`$)4`$@*@1``&BAD&H0````DLH!"DXHC)'
MB@0,B$X```!0````````````````````4P```%4```!6`````````%<```!8
M`````````%D```!:````6P````````!<````````````````````70```&``
M`````````````&$```!C````9````&8`````````:````&L`````````;0``
M`&X```!O````<`````````#(U;)Q6>CM[.;_,*+.WD<MH^#[2>K3[PZGW:-K
M+\6;MMO-XYZ'^9R!:PE#U@TZEPO%B060#13BGB'_Y`ZR`8MOQ+F<0&M_FGQ_
MJ9R;;L7?']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9@%LE9>_!*:^)'
MQ@%#1=7L1^PS.GU!CL7#Y3\L\MO3'?JA;&"YC?$.````````````````````
M`/@"`````````````!(```!&`P`````````````2````L0``````````````
M$@```)0#`````````````!(```!_`P`````````````2````H0$`````````
M````$@```'H"`````````````!(````1```````````````@````(```````
M````````(````(4#`````````````!(```"-`0`````````````2````-`0`
M````````````$@```&X!`````````````!(```"``0`````````````2````
M7P,`````````````$@```"\#`````````````!(````)`P`````````````2
M````+`(`````````````$@```/T``````````````!(````<`@``````````
M```2````L`,`````````````$@```,H!`````````````!(````8!```````
M```````2````UP(`````````````$@```!$#`````````````!(```"8`@``
M```````````2````Z@$`````````````$@```*8!`````````````!(````U
M`@`````````````2````/@0`````````````$@````H$`````````````!(`
M```O`0`````````````2````RP,`````````````$@```#0`````````````
M`!(```#3`P`````````````2````70$`````````````$@```,@`````````
M`````!(```#X`P`````````````2````Q`,`````````````$@```/$#````
M`````````!(```"I`P`````````````2````>`,`````````````$@```/P$
M`````````````!(```!!`0`````````````2````X0,`````````````$@``
M`%P"`````````````!(```!6`P`````````````2````ZP(`````````````
M$@```$X"`````````````!(```"W`P`````````````2````D0(`````````
M````$@```*L!`````````````!(```!G`P`````````````2````O@,`````
M````````$@```*(#`````````````!(```#L```````````````2````0@``
M````````````$@```.@#`````````````!(````"!``````````````2````
MUP``````````````$@```/X!`````````````!(```"%`@`````````````2
M````4`$`````````````$@```(T#`````````````!(```!.`P``````````
M```2````\0(`````````````$@```!T!`````````````!(```!#`@``````
M```````2````5```````````````$@```)L#`````````````!(```#8`0``
M```````````2````8P``````````````$@```!$$`````````````!(```"/
M```````````````2````00,`````````````$@```'@``````````````!(`
M```+`0`````````````2````MP$``-R7!`@`````$@```)T$``"`UP0(!```
M`!$`#P!F!0``8-H$"&Y9```1``\`<`4``&;!!`CM!P``$@`-`)P%``!AI@0(
MT0$``!(`#0"7!```3-<$"``````2``X`+`0``&!1!0@$````(0`8`&\$``!=
MH@0(#0```!(`#0`U!0``0-8$"%H````2``T`H````*R9!`@`````$@```"`%
M```\404(`````!``%P`B!0``/%$%"``````@`!<`*P0``&!1!0@$````(0`8
M`(T$```PU@0(!0```!(`#0"/!0``:J($"+0"```2``T`N@0``#*H!`A1````
M$@`-`"H$``!@404(!````!$`&``E!```.],$"*@"```2``T`Z@0``$2_!`@W
M````$@`-``4%``"\R@0(8````!(`#0!>!```6%$%"``````0`/'_:@0``*1A
M!0@`````$`#Q_Z0$``##S00(#`4``!(`#0`@`P``A-<$"`0````1``\`)@4`
M`&"<!`@`````$@`-`,@$``!7H00(!@$``!(`#0#>!```8*4$"`$!```2``T`
M$04``%11!0@$````$0`7`&H"``"<F00(`````!(```"`!```'J4$"$(````2
M``T`5P0``%A1!0@`````$`#Q_V$%``!0404(!````!$`%P!%!0``9\T$"%P`
M```2``T`+04``!2=!`A$````$@`-`*,"``!D404($P```!$`&`!]!0``,<`$
M"#4!```2``T`+P4``"R7!`@`````$@`+``!L:6)P97)L+G-O+C4N,3``7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M
M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?
M9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V
M7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`
M<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R
M<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N
M`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?
M<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?
M27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L
M+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`7V9P7VAW`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A<G0`
M>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`&YA;65?;&]A9%]M95\R`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,``````"
M``,````#``,````````````#````!````````P`%``8``````````P````,`
M`@`"```````#````!``#`````P````<```````0``P`#``,``P`#`````P``
M``,``@````,``P````@``P`#```````#``,````````````#``,`!@``````
M```#```````#`````P`````````!``$``0`!``$``P`!``$````!``$``P`!
M``$``0`#``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0````$`
M`0`!``4`%@,``!````!@````%&EI#0``"`"I!0``$````!-I:0T```<`LP4`
M`!````!R&6D)```%`+T%```0````$FEI#0``!`#)!0``$````!!I:0T```,`
MTP4````````!``(`QP(``!``````````$FEI#0``!@#)!0``$````!!I:0T`
M``(`TP4```````#P3P4(!@@``&!1!0@%7@``9%$%"`5P````4`4(!P$```10
M!0@'`@``"%`%"`<#```,4`4(!P0``!!0!0@'!0``%%`%"`<&```84`4(!P<`
M`!Q0!0@'3@``(%`%"`<(```D4`4(!PH``"A0!0@'"P``+%`%"`<,```P4`4(
M!PT``#10!0@'#@``.%`%"`</```\4`4(!Q```$!0!0@'$0``1%`%"`<2``!(
M4`4(!Q,``$Q0!0@'%```4%`%"`<5``!44`4(!Q8``%A0!0@'%P``7%`%"`<8
M``!@4`4(!QD``&10!0@'&@``:%`%"`<;``!L4`4(!QP``'!0!0@''0``=%`%
M"`<>``!X4`4(!Q\``'Q0!0@'(```@%`%"`<A``"$4`4(!R(``(A0!0@'(P``
MC%`%"`=J``"04`4(!U<``)10!0@')```F%`%"`<E``"<4`4(!R8``*!0!0@'
M)P``I%`%"`<H``"H4`4(!RD``*Q0!0@'*@``L%`%"`<K``"T4`4(!RP``+A0
M!0@'+0``O%`%"`<N``#`4`4(!R\``,10!0@',```R%`%"`<Q``#,4`4(!S(`
M`-!0!0@',P``U%`%"`<T``#84`4(!S4``-Q0!0@'-@``X%`%"`<W``#D4`4(
M!S@``.A0!0@'.0``[%`%"`<Z``#P4`4(!SL``/10!0@'/```^%`%"`<]``#\
M4`4(!SX```!1!0@'/P``!%$%"`=````(404(!T$```Q1!0@'0@``$%$%"`=#
M```4404(!T0``!A1!0@'10``'%$%"`=&```@404(!T<``"11!0@'2```*%$%
M"`=)```L404(!TH``#!1!0@'2P``-%$%"`=,```X404(!TT``%6)Y5.#[`3H
M`````%N!P[RX``"+D_S___^%TG0%Z)X```#HG04``.C(/P``6%O)P_\U^$\%
M"/\E_$\%"`````#_)0!0!0AH`````.G@_____R4$4`4(:`@```#IT/____\E
M"%`%"&@0````Z<#_____)0Q0!0AH&````.FP_____R404`4(:"````#IH/__
M__\E%%`%"&@H````Z9#_____)1A0!0AH,````.F`_____R4<4`4(:#@```#I
M</____\E(%`%"&A`````Z6#_____)210!0AH2````.E0_____R4H4`4(:%``
M``#I0/____\E+%`%"&A8````Z3#_____)3!0!0AH8````.D@_____R4T4`4(
M:&@```#I$/____\E.%`%"&AP````Z0#_____)3Q0!0AH>````.GP_O___R5`
M4`4(:(````#IX/[___\E1%`%"&B(````Z=#^____)4A0!0AHD````.G`_O__
M_R5,4`4(:)@```#IL/[___\E4%`%"&B@````Z:#^____)510!0AHJ````.F0
M_O___R584`4(:+````#I@/[___\E7%`%"&BX````Z7#^____)6!0!0AHP```
M`.E@_O___R5D4`4(:,@```#I4/[___\E:%`%"&C0````Z4#^____)6Q0!0AH
MV````.DP_O___R5P4`4(:.````#I(/[___\E=%`%"&CH````Z1#^____)7A0
M!0AH\````.D`_O___R5\4`4(:/@```#I\/W___\E@%`%"&@``0``Z>#]____
M)810!0AH"`$``.G0_?___R6(4`4(:!`!``#IP/W___\EC%`%"&@8`0``Z;#]
M____)9!0!0AH(`$``.F@_?___R644`4(:"@!``#ID/W___\EF%`%"&@P`0``
MZ8#]____)9Q0!0AH.`$``.EP_?___R6@4`4(:$`!``#I8/W___\EI%`%"&A(
M`0``Z5#]____):A0!0AH4`$``.E`_?___R6L4`4(:%@!``#I,/W___\EL%`%
M"&A@`0``Z2#]____);10!0AH:`$``.D0_?___R6X4`4(:'`!``#I`/W___\E
MO%`%"&AX`0``Z?#\____)<!0!0AH@`$``.G@_/___R7$4`4(:(@!``#IT/S_
M__\ER%`%"&B0`0``Z<#\____)<Q0!0AHF`$``.FP_/___R704`4(:*`!``#I
MH/S___\EU%`%"&BH`0``Z9#\____)=A0!0AHL`$``.F`_/___R7<4`4(:+@!
M``#I</S___\EX%`%"&C``0``Z6#\____)>10!0AHR`$``.E0_/___R7H4`4(
M:-`!``#I0/S___\E[%`%"&C8`0``Z3#\____)?!0!0AHX`$``.D@_/___R7T
M4`4(:.@!``#I$/S___\E^%`%"&CP`0``Z0#\____)?Q0!0AH^`$``.GP^___
M_R4`404(:``"``#IX/O___\E!%$%"&@(`@``Z=#[____)0A1!0AH$`(``.G`
M^____R4,404(:!@"``#IL/O___\E$%$%"&@@`@``Z:#[____)111!0AH*`(`
M`.F0^____R48404(:#`"``#I@/O___\E'%$%"&@X`@``Z7#[____)2!1!0AH
M0`(``.E@^____R4D404(:$@"``#I4/O___\E*%$%"&A0`@``Z4#[____)2Q1
M!0AH6`(``.DP^____R4P404(:&`"``#I(/O___\E-%$%"&AH`@``Z1#[____
M)3A1!0AH<`(``.D`^___`````#'M7HGA@^3P4%12:##6!`AH0-8$"%%6:#O3
M!`CH2_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/7A1!0@`=3^A?%$%"+OP
M3@4(@>OL3@4(P?L"@^L!.=AS'HVV`````(/``:-\404(_Q2%[$X%"*%\404(
M.=ARZ,8%>%$%"`&#Q`1;7<.-="8`C;PG`````%6)Y8/L&*'T3@4(A<!T$K@`
M````A<!T"<<$)/1.!0C_T,G#D%6)Y8/L*,=%](C7!`C'!"0`````Z+_^__^+
M`(D$).BE^___BU7TB50D#,=$)`B<F00(QT0D!)+7!`B)!"3H9O[__\G#58GE
M4X'L-!```(M%#(F%Y.___XM%$(F%X.___V6A%````(E%]#'`N*[7!`C'1"0(
M_P\``(V5].___XE4)`2)!"3H?OW__XF%\.___X.]\.___P!^'(N%\.___X/H
M`0^VA`7T[___A,!U!X.M\.___P&#O?#O__\`?F*+A?#O__^)1"0(QT0D!"\`
M``"-A?3O__^)!"3HBOW__X7`=#Z+G?#O___'!"0`````Z.3]__^+`(D$).C*
M^O__B5PD#(V5].___XE4)`B+E>3O__^)5"0$B00DZ`K\___K,L<$)`````#H
MK/W__XL`B00DZ)+Z__^+E>#O__^)5"0(BY7D[___B50D!(D$).A6^O__BT7T
M93,%%````'0%Z%7\__^!Q#00``!;7<-5B>575E.#["R+?0B%_W0)H6!1!0B%
MP'4'N`````#K?(G[ZP.#PP$/M@.$P'0'#[8#/#UU[XG:B?B)T2G!B4WDBS5@
M404(ZTF+1>2)1"0(B7PD!(D<).BQ_/__A<!U+XM%Y(T$`P^V`#P]=2*)\J%@
M404(B=$IP8G(P?@"B<*+10R)$(M%Y(/``8T$`^L.@\8$BQZ%VW6QN`````"#
MQ"Q;7E]=PU6)Y8/L*(U%](E$)`2+10B)!"3H1/___\G#58GE5U93@^PLBW4,
M#[8&/#UU`X/&`8DT).BP^O__B47DC47@B40D!(M%"(D$).@/____B<.%VW0R
MB1PDZ(WZ__\[1>0/@M\````/M@:(`P^V`X3`#Y7`@\,!@\8!A,!UZ;@`````
MZ6`!``"+'6!1!0B_`````.L&@\,$@\<!BP.%P'7TH:!A!0B%P'0QC4<"P>`"
MB<*A8%$%"(E4)`2)!"3H&/C__Z-@404(H6!1!0B%P'58N/_____I#0$``,<%
MH&$%"`$```"-1P+!X`*)!"3HF/K__XG#A=MU"KC_____Z>4```")^(T4A0``
M``"A8%$%"(E4)`B)1"0$B1PDZ.KZ__^)'6!1!0CK`9"A8%$%"(GZ@\(!P>("
M`=#'``````")^(E%X.L!D(M=".L#@\,!#[8#A,!T!P^V`SP]=>^A8%$%"(M5
MX,'B`HT\$(G:BT4(B=$IP8G(`T7D@\`"B00DZ`?Z__^)!XL'A<!U![C_____
MZU6A8%$%"(M5X,'B`@'0BQCK`X/#`8M%"`^V`(@##[8#A,`/E<"#10@!A,!T
M!P^V`SP]==[&`SV#PP$/M@:(`P^V`X3`#Y7`@\,!@\8!A,!UZ;@`````@\0L
M6UY?7<-5B>53@^PDZR&A8%$%"(M5],'B`HT<$(U#!(L`B0.+`X7`=`6#PP3K
M[I"-1?2)1"0$BT4(B00DZ#/]__^%P'7)@\0D6UW#58GE@>PH(```9:$4````
MB47T,<#'A>S?__\`````Z"+V__^ZP=<$",=$)`S-UP0(B40D"(E4)`2-A?/O
M__^)!"3HW_7__XF%Z-___X.]Z-___P!Y"K@`````Z90```"-A?/O___'1"0(
M`!```(V5\M___XE4)`2)!"3H1OG__XF%Z-___X.]Z-___P!Y![@`````ZUZ+
MA>C?__^#P`&)!"3HK_C__XF%[-___X.][-___P!U![@`````ZS>+A>C?__^)
M1"0(C87RW___B40D!(N%[-___XD$).BW]___BX7HW___`X7LW___Q@``BX7L
MW___BU7T93,5%````'0%Z''X___)PU6)Y8/L".CO_O__R<-5B>6![%@0``"+
M10B)A=3O__^+10R)A=#O__]EH10```")1?0QP,<$)-'7!`CHB/S__XF%Y.__
M_Z%$404(B40D!(N%U.___XD$).CC]___A<!T(8N%U.___XE$)`3'!"3:UP0(
MZ&O\__^+A=3O___I+0(``(N%U.___XD$).@@]___B87L[___H4A1!0B)1"0$
MBX70[___B00DZ./W__^)A?#O___IS@$``(N%\.___P^V`(3`=0K'A?#O___G
MUP0(@[WD[___`'0\BX7P[___B40D!(N%Y.___XD$).C`^/__A<!U(*%(404(
MB40D!,<$)`````#HA_?__XF%\.___^ER`0``BX7P[___B00DZ([V__^)A>CO
M___K%H.MZ.___P&+A>CO__\#A?#O___&``"+A>CO__^#Z`$#A?#O__\/MA"A
M1%$%"`^V`#C"=,R+A>CO__^#P`$#A>SO__\]_P\``'XABX74[___B40D!,<$
M)-K7!`CH6/O__XN%U.___^D:`0``BQ5$404(N.G7!`B+C=3O__^)3"00B50D
M#(N5\.___XE4)`B)1"0$C87T[___B00DZ%;S___'!"0`````Z+KW__^+`(D$
M).B@]/__B00DZ,CV__^-E?3O__^)1"0$B10DZ$HR``"%P'5MQP0D`````.B&
M]___BP")!"3H;/3__XD$).B4]O__BT`0)0#P```]`(```'5`QT0D!`$```"-
MA?3O__^)!"3HK_3__X7`=2:-A?3O__^)1"0$QP0DVM<$".B'^O__C87T[___
MB00DZ!?W___K1*%(404(B40D!,<$)`````#H$/;__XF%\.___X.]\.___P`/
MA27^__^+A=3O__^)1"0$QP0DVM<$".@Y^O__BX74[___BU7T93,5%````'0%
MZ+#U___)PU6)Y8/L$(M%"(E%_(M%"(E%^.L?BT7X#[80H411!0@/M@`XPG4)
MBT7X@\`!B47\@T7X`8M%^`^V`(3`==>+1?S)PU6)Y5.#[!2#?0@`=`J+10@/
MM@"$P'41QP0DY]<$".A9]O__Z=,```"+10B)!"3H>?3__X/H`8G#`UT(ZP.#
MZP$[70AV%`^V$Z%$404(#[8`.,)TZ>L#@^L!.UT(=@\/MA.A1%$%"`^V`#C"
M=>D[70AU+`^V$Z%$404(#[8`.,)U#L<$).?7!`CH[_7__^MLH411!0B)!"3H
MX/7__^M=@^L!.UT(=@\/MA.A1%$%"`^V`#C"=.F)VHM%"(G1*<&)R(/``CT`
M$```=@>X`````.LJB=J+10B)T2G!B<B#P`&)1"0(BT4(B40D!,<$)*!1!0CH
M]O'__[B@404(@\046UW#58GE@^Q(9:$4````B47T,<"AG-@$"(E%TJ&@V`0(
MB476H:38!`B)1=JAJ-@$"(E%WJ&LV`0(B47BH;#8!`B)1>:AM-@$"(E%ZJ&X
MV`0(B47N#[<%O-@$"&:)1?+'!"3PUP0(Z$CZ___'!"0`V`0(Z#SZ___'!"31
MUP0(Z##Z___'!"0,V`0(Z"3Z___'!"06V`0(Z!CZ___'!"0@V`0(Z`SZ___'
M!"3:UP0(Z`#Z___'!"0JV`0(Z/3Y___'!"0SV`0(Z.CY___'!"0^V`0(Z._W
M__^)1<R#?<P`=!.+1<R)1"0$QP0D%M@$".CM]___QP0D3]@$".C']___B47,
M@WW,`'03BT7,B40D!,<$)&'8!`CHQ??__\<$)&S8!`CHG_?__XE%S(-]S`!T
M%8M%S(E$)`3'!"31UP0(Z)WW___K:,<$)'S8!`CH=??__XE%S(-]S`!T%8M%
MS(E$)`3'!"0,V`0(Z'/W___K/HU%TH/`$8E%S,=$)`@*````QT0D!(W8!`B+
M1<R)!"3HF_/__X7`=1:+1<R#P`J)1"0$QP0D#-@$".@S]___QT0D!)C8!`C'
M!"3PUP0(Z!_W__^+1?1E,P44````=`7HG/+__\G#58GE@^PHH4Q1!0B#^/]U
M.L<$)`S8!`CHUO;__XE%](-]]`!T&XM%]`^V`(3`=!&+1?0/M@`\,'0'N`$`
M``#K!;@`````HTQ1!0BA3%$%",G#58GE4X'L<`$``(M%"(/`'(E%],=%^```
M``#K1HM%](L`B47P@T7T!(M%^(M5\(G1P>$8BU7PP>((@>(``/\`"=&+5?#!
MZ@B!X@#_```)T8M5\,'J&`G*B92%F/[__X-%^`&#??@/?K3'1?@0````ZU^+
M1?B+5?B#Z@.+C)68_O__BU7X@^H(BY25F/[__S'1BU7X@^H.BY25F/[__S'1
MBU7X@^H0BY25F/[__S'*B92%F/[__XM%^(M5^(N4E9C^___!RA^)E(68_O__
M@T7X`8-]^$]^FXM%"(L`B47LBT4(BT`$B47HBT4(BT`(B47DBT4(BT`,B47@
MBT4(BT`0B47<C868_O__B478BT7LB<'!R1N+1>2+5>@APHM%Z/?0(T7@"="-
M!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BT7HBU7L
M(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+
M1=R)P<')&XM%[(M5\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"
M6HE%X(-%V`3!3?`"BT7@B<'!R1N+1?"+5=PAPHM%W/?0(T7L"="-!`&)P@-5
MZ(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;BT7<BU7@(<*+1>#W
MT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78!,%-X`*+1>B)P<')
M&XM%X(M5Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%
MV`3!3>0"BT7LB<'!R1N+1>2+5>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`
MC00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BT7HBU7L(<*+1>SWT"-%Y`G0
MC00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM%[(M5
M\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!3?`"
MBT7@B<'!R1N+1?"+5=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY
M@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;BT7<BU7@(<*+1>#WT"-%\`G0C00!B<(#
M5>R+1=B+`(T$`@69>8):B47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y"'"BT7D
M]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!3>0"BT7LB<'!
MR1N+1>2+5>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#
M1=@$P4WH`HM%\(G!P<D;BT7HBU7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+
M`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM%[(M5\"'"BT7P]]`C1>@)
MT(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!3?`"BT7@B<'!R1N+1?"+
M5=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<
M`HM%Y(G!P<D;BT7<BU7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69
M>8):B47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y"'"BT7D]]`C1=P)T(T$`8G"
M`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!3>0"BT7LB<'!R1N+1>2+5>@APHM%
MZ/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!
MP<D;BT7HBU7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<
M@T78!,%-[`*+1=R)P<')&XM%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6A
MZ]ENB47@@T78!,%-\`*+1>")P<')&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+
M`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#
M5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<
MC00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5
MZ#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%-Z`*+1?")P<')
M&XM%Z(M5[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%-[`*+
M1=R)P<')&XM%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78
M!,%-\`*+1>")P<')&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]EN
MB47D@T78!,%-W`*+1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$
M`@6AZ]ENB47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<C00!B<(#5?"+
M1=B+`(T$`@6AZ]ENB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5Z#'0,T7@C00!
MB<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%-Z`*+1?")P<')&XM%Z(M5[#'0
M,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%-[`*+1=R)P<')&XM%
M[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")
MP<')&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-
MW`*+1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H
M@T78!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6A
MZ]ENB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5Z#'0,T7@C00!B<(#5=R+1=B+
M`(T$`@6AZ]ENB47P@T78!,%-Z`*+1?")P<')&XM%Z(M5[#'0,T7DC00!B<(#
M5>"+1=B+`(T$`@6AZ]ENB47<@T78!,%-[`*+1=R)P<')&XM%[(M5\#'0,T7H
MC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM%\(M5
MW#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P\'+
M&XM%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78BP"-!`(M)$/D<(E%
MZ(-%V`3!3>`"BT7HB</!RQN+1=R+5>`)T"-%Y(M5W(M-X"'*"="-!`.)P@-5
M\(M%V(L`C00"+21#Y'")1>R#1=@$P4WD`HM%[(G#P<L;BT7@BU7D"=`C1>B+
M5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%-Z`*+1?")
MP\'+&XM%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@BT78BP"-!`(M)$/D
M<(E%W(-%V`3!3>P"BT7<B</!RQN+1>B+5>P)T"-%\(M5Z(M-["'*"="-!`.)
MP@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P4WP`HM%X(G#P<L;BT7LBU7P"=`C
M1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78!,%-W`*+
M1>2)P\'+&XM%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78BP"-!`(M
M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+1=R+5>`)T"-%Y(M5W(M-X"'*"="-
M!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P4WD`HM%[(G#P<L;BT7@BU7D
M"=`C1>B+5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%-
MZ`*+1?")P\'+&XM%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@BT78BP"-
M!`(M)$/D<(E%W(-%V`3!3>P"BT7<B</!RQN+1>B+5>P)T"-%\(M5Z(M-["'*
M"="-!`.)P@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P4WP`HM%X(G#P<L;BT7L
MBU7P"=`C1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78
M!,%-W`*+1>2)P\'+&XM%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"`U7LBT78
MBP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+1=R+5>`)T"-%Y(M5W(M-
MX"'*"="-!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P4WD`HM%[(G#P<L;
MBT7@BU7D"=`C1>B+5>"+3>0AR@G0C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P
M@T78!,%-Z`*+1?")P\'+&XM%Y(M5Z`G0(T7LBU7DBTWH(<H)T(T$`XG"`U7@
MBT78BP"-!`(M)$/D<(E%W(-%V`3!3>P"BT7<B</!RQN+1>B+5>P)T"-%\(M5
MZ(M-["'*"="-!`.)P@-5Y(M%V(L`C00"+21#Y'")1>"#1=@$P4WP`HM%X(G#
MP<L;BT7LBU7P"=`C1=R+5>R+3?`AR@G0C00#B<(#5>B+1=B+`(T$`BTD0^1P
MB47D@T78!,%-W`*+1>2)P\'+&XM%\(M5W`G0(T7@BU7PBTW<(<H)T(T$`XG"
M`U7LBT78BP"-!`(M)$/D<(E%Z(-%V`3!3>`"BT7HB</!RQN+1=R+5>`)T"-%
MY(M5W(M-X"'*"="-!`.)P@-5\(M%V(L`C00"+21#Y'")1>R#1=@$P4WD`HM%
M[(G!P<D;BT7DBU7H,=`S1>"-!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$
MP4WH`HM%\(G!P<D;BT7HBU7L,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)
M1=R#1=@$P4WL`HM%W(G!P<D;BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"
M+2H^G36)1>"#1=@$P4WP`HM%X(G!P<D;BT7PBU7<,=`S1>R-!`&)P@-5Z(M%
MV(L`C00"+2H^G36)1>2#1=@$P4W<`HM%Y(G!P<D;BT7<BU7@,=`S1?"-!`&)
MP@-5[(M%V(L`C00"+2H^G36)1>B#1=@$P4W@`HM%Z(G!P<D;BT7@BU7D,=`S
M1=R-!`&)P@-5\(M%V(L`C00"+2H^G36)1>R#1=@$P4WD`HM%[(G!P<D;BT7D
MBU7H,=`S1>"-!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$P4WH`HM%\(G!
MP<D;BT7HBU7L,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P4WL
M`HM%W(G!P<D;BT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"+2H^G36)1>"#
M1=@$P4WP`HM%X(G!P<D;BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"+2H^
MG36)1>2#1=@$P4W<`HM%Y(G!P<D;BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`
MC00"+2H^G36)1>B#1=@$P4W@`HM%Z(G!P<D;BT7@BU7D,=`S1=R-!`&)P@-5
M\(M%V(L`C00"+2H^G36)1>R#1=@$P4WD`HM%[(G!P<D;BT7DBU7H,=`S1>"-
M!`&)P@-5W(M%V(L`C00"+2H^G36)1?"#1=@$P4WH`HM%\(G!P<D;BT7HBU7L
M,=`S1>2-!`&)P@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P4WL`HM%W(G!P<D;
MBT7LBU7P,=`S1>B-!`&)P@-5Y(M%V(L`C00"+2H^G36)1>"#1=@$P4WP`HM%
MX(G!P<D;BT7PBU7<,=`S1>R-!`&)P@-5Z(M%V(L`C00"+2H^G36)1>2#1=@$
MP4W<`HM%Y(G!P<D;BT7<BU7@,=`S1?"-!`&)P@-5[(M%V(L`C00"+2H^G36)
M1>B#1=@$P4W@`HM%Z(G!P<D;BT7@BU7D,=`S1=R-!`&)P@-5\(M%V(L`C00"
M+2H^G36)1>R#1=@$P4WD`HM%[(G!P<D;BT7DBU7H,=`S1>"-!`&)P@-5W(M%
MV(L`C00"+2H^G36)1?"#1=@$P4WH`HM%\(G!P<D;BT7HBU7L,=`S1>2-!`&)
MP@-5X(M%V(L`C00"+2H^G36)1=R#1=@$P4WL`HM%"(L`B<(#5=R+10B)$(M%
M"(M`!(G"`U7PBT4(B5`$BT4(BT`(B<(#5>R+10B)4`B+10B+0`R)P@-5Z(M%
M"(E0#(M%"(M`$(G"`U7DBT4(B5`0@<1P`0``6UW#58GEBT4(QP`!(T5GBT4(
MQT`$B:O-[XM%",=`"/[<NIB+10C'0`QV5#(0BT4(QT`0\.'2PXM%",=`%```
M``"+10C'0!@`````BT4(QT!<`````%W#58GE@^PHBT4(BT`4BU40P>(#`=")
M1?"+10B+0!0[1?!V#XM%"(M`&(U0`8M%"(E0&(M%"(M5\(E0%(M%"(M`&(M5
M$,'J'8T4$(M%"(E0&(M%"(M`7(7`#X2L````BT4(BT!<ND````")T2G!B<B)
M1?2+1?0[11!^!HM%$(E%](M%](M5"(U*'(M5"(M27(T4$8E$)`B+10R)1"0$
MB10DZ,;=__^+1?0I11"+1?0!10R+10B+0%R)P@-5](M%"(E07(M%"(M`7(/X
M0'5JBT4(B00DZ"KL___K,(M%"(U0',=$)`A`````BT4,B40D!(D4).ATW?__
M@T4,0(-M$$"+10B)!"3H^.O__X-]$#]_RHM%$(M5"(/"'(E$)`B+10R)1"0$
MB10DZ#_=__^+10B+51")4%SK`9#)PU6)Y8/L!(M%#(D$).BWZ___BT4,BP#!
MZ!B)PHM%"(@0BT4(C5`!BT4,BP#!Z!"(`HM%"(U0`HM%#(L`P>@(B`*+10B-
M4`.+10R+`(@"BT4(C5`$BT4,BT`$P>@8B`*+10B-4`6+10R+0`3!Z!"(`HM%
M"(U0!HM%#(M`!,'H"(@"BT4(C5`'BT4,BT`$B`*+10B-4`B+10R+0`C!Z!B(
M`HM%"(U0"8M%#(M`",'H$(@"BT4(C5`*BT4,BT`(P>@(B`*+10B-4`N+10R+
M0`B(`HM%"(U0#(M%#(M`#,'H&(@"BT4(C5`-BT4,BT`,P>@0B`*+10B-4`Z+
M10R+0`S!Z`B(`HM%"(U0#XM%#(M`#(@"BT4(C5`0BT4,BT`0P>@8B`*+10B-
M4!&+10R+0!#!Z!"(`HM%"(U0$HM%#(M`$,'H"(@"BT4(C5`3BT4,BT`0B`+)
MPU6)Y8/L*(M%#(M`%(E%\(M%#(M`&(E%[(M%\,'H`X/@/XE%](M%#(U0'(M%
M](T$`L8`@(-%]`&#??0X?E.X0````"M%](M5#(U*'(M5](T4$8E$)`C'1"0$
M`````(D4).@YVO__BT4,B00DZ`7J__^+10R#P!S'1"0(.````,=$)`0`````
MB00DZ!#:___K*+@X````*T7TBU4,C4H<BU7TC101B40D",=$)`0`````B10D
MZ.;9__^+1>S!Z!B)PHM%#(A05(M%[,'H$(G"BT4,B%!5BT7LP>@(B<*+10R(
M4%:+1>R)PHM%#(A05XM%\,'H&(G"BT4,B%!8BT7PP>@0B<*+10R(4%F+1?#!
MZ`B)PHM%#(A06HM%\(G"BT4,B%!;BT4,B40D!(M%"(D$).AY_?__R<-5B>6#
M["C'1?0`````QT7P`````.COVO__B00DZ,?:__^)1?"#??``=`B+1?"+`(E%
M](M%],G#58GE@^P8QP0D`````.A?W/__BP")!"3H1=G__XD$).AMV___B40D
M!(M%"(D$).@R%P``A<!U>,<$)`````#H+MS__XL`B00DZ!39__^)!"3H/-O_
M_XM`$"4`\```/0!```!T+<<$)`````#H`=S__XL`B00DZ.?8__^)!"3H#]O_
M_XM`$"4`\```/0"@``!U'L=$)`0"````BT4(B00DZ"W9__^%P'4'N`$```#K
M!;@`````R<-5B>53@^Q4QT7T`````,=%\`````#'1="^V`0(QT74SM@$",=%
MV-;8!`C'1=SCV`0(QT7@Z-@$",=%Y/K8!`C'1>@`````QT7L`````.G%````
MBT7TB00DZ);>__^)1?"#??``=`J+1?`/M@"$P'47BT4(B40D!(M%](D$).B+
MWO__Z8P```"+10B)1"0$BT7PB00DZ-+9__^%P'5VBT4(B00DZ#/9__^)PZ%(
M404(B00DZ"39__\!PXM%\(D$).@7V?__C00#@\`"B00DZ*G9__^)1>B+%4A1
M!0BXZ=<$"(M-\(E,)!")5"0,BU4(B50D"(E$)`2+1>B)!"3H2M;__XM%Z(E$
M)`2+1?2)!"3H^MW__X-%[`&+1>R+1(70B47TBT7T#[8`A,`/A2/___^#Q%1;
M7<-5B>575E.![%R!``"+10B)A<1^__]EH10```")1>0QP,>%.'___P````#'
MA31___\`````QX4P?___`````,>%Z'[___O8!`C'A>Q^__\#V00(QX7P?O__
MY]<$",>%]'[___K8!`C'A=!^__]AV`0(QX74?O__"-D$",>%V'[__P_9!`C'
MA=Q^__\7V00(QX7@?O__'-D$",>%Y'[___K8!`C'A?A^__\@V00(QX7\?O__
M)=D$",>%`'____K8!`C'A2Q___\NV00(QX4H?___^M@$",>%)'___P````#'
MA2!___\`````QX4<?___`````,>%#'___P````#'!"31UP0(Z+;<__^)A3!_
M__^#O3!___\`="Z+A3!___\/M@"$P'0ABX4P?___B00DZ)G]__^+A3!___^)
M!"3H-MG__^F,!@``Z)3\__^)A2!___^#O2!___\`=6W'A4!___\`````ZSB+
MA31___^)!"3H2]S__XF%,'___X.],'___P!T%(N%,'___XD$).CFV/__B84@
M?___@X5`?___`8.]('___P!U((N%0'___XN$A?A^__^)A31___^+A31___\/
MM@"$P'6?@[T@?___`'4,QX4@?___,]D$".M0BX4@?___B84\?___ZS7H.-;_
M_XL0BX4\?___#[8`#[[``<"-!`(/MP`/M\"#X`B%P'4)BX4\?___Q@!?@X4\
M?___`8N%/'___P^V`(3`=;['A4!___\`````ZTJ+A31___^)!"3H>=O__XF%
M,'___X.],'___P!T)HN%,'___XD$).BS^___A<!T%(N%,'___XD$).@"V/__
MB84X?___@X5`?___`8.].'___P!U((N%0'___XN$A=!^__^)A31___^+A31_
M__\/M@"$P'6-QX5`?___`````.LMBX4P?___B00DZ%'[__^%P'04BX4P?___
MB00DZ*#7__^)A3A___^#A4!___\!@[TX?___`'4@BX5`?___BX2%Z'[__XF%
M,'___XN%,'___P^V`(3`=:J+A3A___^)!"3HC-7__XG#BX4L?___B00DZ'S5
M__\!PXN%('___XD$).ALU?__`<.+A2A___^)!"3H7-7__XT$`P4`!```B84,
M?___BX4,?___B00DZ.#5__^)A1Q___^+%411!0BX.MD$"(N-('___XE,)!2+
MC2Q___^)3"00B50D#(N5.'___XE4)`B)1"0$BX4<?___B00DZ&O2___'1"0$
M[0$``(N%''___XD$).B%TO__QP0DX]@$".CQV?__B84P?___@[TP?___`'0J
MBX4P?___B00DZ(S6__^)PHN%Q'[__XL`B50D!(D$).@$W?__B84D?___@[TD
M?___`'4.BX7$?O__BP")A21____HJN+__X7`#X5S`@``QT0D!`````"+A21_
M__^)!"3H]M7__XF%&'___X.]&'___P`/A$H"``#'1"0,`@```,=$)`3N____
MQT0D"/____^+A1A___^)!"3HC=+__\=$)`@&````C85$?___B40D!(N%&'__
M_XD$).CMTO__#[:%1'___X3`#X7:````#[:%17___SQ##X7+````#[:%1G__
M_SQ!#X6\````#[:%1W___SQ##X6M````#[:%2'___SQ(#X6>````#[:%27__
M_SQ%#X6/````QT0D#`(```#'1"0$QO___\=$)`C_____BX48?___B00DZ.W1
M___'1"0(*0```(V%1'___XE$)`2+A1A___^)!"3H3=+__XLU1%$%"+M#V00(
MBX4<?___B00DZ%33__\#A1Q___^+E2A___^)5"00C95$?___B50D#(ET)`B)
M7"0$B00DZ)K0__^0Z24"``"-A43___^)!"3H./3__^LBBX44?___B40D"(V%
M1'___XE$)`2-A43___^)!"3H:/3__\=$)`@`@```C85$?___B40D!(N%&'__
M_XD$).BRT?__B844?___@[T4?___`'^OBX48?___B00DZ"73__^-A43___^)
M1"0$C470B00DZ*+V___'A1!___\`````ZSF+A1!___\/MD0%T`^VR+I0V00(
MBX40?___`<")PXU%IP'8B4PD"(E4)`2)!"3HTL___X.%$'___P&#O1!___\3
M?K[&1<\`BS5$404(NT/9!`B+A1Q___^)!"3H-=+__P.%''___XN5*'___XE4
M)!"-5:>)5"0,B70D"(E<)`2)!"3H?L___^D*`0``QX4(?___`````(N%''__
M_XD$).CQT?__B84$?___QT0D!)C8!`C'!"0,V`0(Z`G7___H8L___XG#BSU$
M404(OE79!`B+A1Q___^)!"3HM]'__P.%''___XN5*'___XE4)!")7"0,B7PD
M"(ET)`2)!"3H`\___^MGBX4$?___BY4<?___C00"Q@``@X4(?___`>@#S___
MB<.+/411!0B^8=D$"(N%''___XD$).A8T?__`X4<?___BY4H?___B50D%(N5
M"'___XE4)!")7"0,B7PD"(ET)`2)!"3HFL[__\=$)`3M`0``BX4<?___B00D
MZ+3.__^#^/]U$.AJSO__BP"#^!$/A&[___^+A1Q___^)1"0$QP0DT=<$".@;
MUO__BX4<?___B00DZ`#W__^+A1Q___^+5>1E,Q44````=`7HA-'__X'$7($`
M`%M>7UW#58GE4X'LA````,=%[`````"#?0@`#X1!`0``BT4(#[8`A,`/A#8!
M``"+10B)!"3HY<___XE%](-]]``/A>H```#I&@$``(M%\(/`$\=$)`3GUP0(
MB00DZ%W2__^%P`^$R````(M%\(/`$\=$)`1PV00(B00DZ#_2__^%P`^$J@``
M`(M%"(D$).@LT/__B<.+1?"#P!.)!"3H'-#__XT$`X/``HE%Z(M%Z(D$).BH
MT/__B47LBT7PC5`3N'/9!`B)5"0,BU4(B50D"(E$)`2+1>R)!"3H4,W__XM%
M[(U5B(E4)`2)!"3H8@P``(/X_W0<BT68)0#P```]`$```'4-BT7LB00DZ/;^
M___K"XM%[(D$).BRS___BT7LB00DZ*?.___'1>P`````ZP&0BT7TB00DZ%+/
M__^)1?"#??``#X4"____BT7TB00DZ,K/__^+10B)!"3H+]#__^L$D.L!D('$
MA````%M=PU6)Y8/L*(M%"(D$).B3VO__B47TBT7TB00DZ$/:__^)1?#H3]W_
M_X7`=#.#?0@`="V+10@/M@"$P'0CQT0D!"[9!`B+1?")!"3HDL___SM%\'4+
MBT4(B00DZ#G^___)PU6)Y5.#[!3'!"0`````Z+W0__^+`(D$).BCS?__B00D
MZ$O,__^+`(M8!,<$)`````#HFM#__XL`B00DZ(#-__^)!"3HR,S__P^V`(A#
M&,<$)`````#H=M#__XL`B00DZ%S-__^)!"3H!,S__XL`BU@$QP0D`````.A3
MT/__BP")!"3H.<W__XD$).B1S/__BP`/MT`09B7_`6:)0QK'!"0`````Z"?0
M__^+`(D$).@-S?__B00DZ+7+__^+`(M8!,<$)`````#H!-#__XL`B00DZ.K,
M___'1"0(`````,=$)`3ZV`0(B00DZ&+/__^)0QS'!"0`````Z-//__^+`(D$
M).BYS/__B00DZ&'+__^+`(M8!,<$)`````#HL,___XL`B00DZ);,__^)!"3H
MOLO__XL`B4,@QP0D`````.B-S___BP")!"3H<\S__XD$).@;R___BP"+6`3'
M!"0`````Z&K/__^+`(D$).A0S/__B00DZ&C.__^+`(7`="7'!"0`````Z$;/
M__^+`(D$).@LS/__B00DZ$3.__^+`(M`;.L%N`````")0R3'!"0`````Z!G/
M__^+`(D$).C_R___B00DZ*?*__^+`(M`!,=`*`````#'!"0`````Z._.__^+
M`(D$).C5R___B00DZ'W*__^+`(M`!,=`+`````#'!"0`````Z,7.__^+`(D$
M).BKR___B00DZ%/*__^+`(M8!,<$)`````#HHL[__XL`B00DZ(C+__^)!"3H
M4,[__XL`B4,P@\046UW#58GE@^P8QP0D`````.ASSO__BP")!"3H6<O__\=$
M)`3_____B00DZ)G+___'!"0`````Z$W.__^+`(D$).@SR___QT0D"`````#'
M1"0$',L$"(D$).A[SO__R<-5B>564X/L,,=%X`````#'!"0`````Z`[.__^+
M`(D$).CTRO__B00DZ&S+___&``''!"3PUP0(Z"71__^)1=R#?=P`=!>+1=P/
MM@`\,74-BT7<@\`!#[8`A,!T!>@]V/__QP0D`````.B\S?__BP")!"3HHLK_
M_\=$)`P+````QT0D"`$```#'1"0$>=D$"(D$).A"RO__B47T@WWT``^$-@$`
M`(M%](M`#(M`&(E%\,=%Y`$```#IO@```(M%Y(U8_\<$)`````#H6\W__XL`
MB00DZ$'*___'1"0,`````(E<)`B+5?")5"0$B00DZ*;+__^)1>R#?>P`#X2*
M````BT7LBP"+0`@E``0``(7`=`J+1>R+`(M`#.LWBT7LBQC'!"0`````Z/W,
M__^+`(D$).CCR?__QT0D#`(```#'1"0(`````(E<)`2)!"3H-\W__XL5C%$%
M"(M-Y,'A`@'*BQ*)1"0$B10DZ-O,__^%P'4;@T7@`8-%Y`&AB%$%"#E%Y`^,
M-/___^L$D.L!D*&(404(@^@!.T7@=3_'1>0!````ZRS'!"0`````Z'G,__^+
M`(D$).A?R?__BU7PB50D!(D$).@`R?__B47H@T7D`:&(404(.47D?,K'!"0`
M````Z$/,__^+`(D$).@IR?__QT0D#`4```#'1"0(`0```,=$)`1^V00(B00D
MZ,G(__^)1?2#??0`='"+1?2+0`R+&,<$)`````#H_,O__XL`B00DZ.+(___'
M1"0(@-D$"(E<)`2)!"3HKLC__XM%](M`#(L`BT`()0``0`"%P'0JBT7TBT`,
MBQC'!"0`````Z+;+__^+`(D$).B<R/__B5PD!(D$).APRO__QP0D`````.B4
MR___BP")!"3H>LC__\=$)`P%````QT0D"`$```#'1"0$A=D$"(D$).@:R/__
MB47T@WWT``^$A````,=%V`````#'!"3:UP0(Z(+.__^)1=B#?=@`=#.+1?2+
M0`R+&,<$)`````#H+<O__XL`B00DZ!/(__^+5=B)5"0(B5PD!(D$).C@Q___
MZS6AC%$%"(LPBT7TBT`,BQC'!"0`````Z//*__^+`(D$).C9Q___B70D"(E<
M)`2)!"3H1<S__\<$)`````#HS<K__XL`B00DZ+/'__^)!"3H*\C__\8``,<$
M)`````#HK,K__XL`B00DZ)+'__^)!"3HRLK__\<``````,<$)-'7!`CHP,W_
M_Z.$404(H811!0B%P`^%``$``*&,404(B00DZ./O__^CA%$%"(L=C%$%"(M%
M](M`#(L`BT`()0`$``"%P'0-BT7TBT`,BP"+0`SK.HM%](M`#(LPQP0D````
M`.@IRO__BP")!"3H#\?__\=$)`P"````QT0D"`````")="0$B00DZ&/*__^)
M7"0$B00DZ`?(__^)1>2+1?2+0`R+`(M`""4`!```A<!T#8M%](M`#(L`BT`,
MZSJ+1?2+0`R+&,<$)`````#HO\G__XL`B00DZ*7&___'1"0,`@```,=$)`@`
M````B5PD!(D$).CYR?__BQ6,404(BQ*+3>2)3"0,B40D"(E4)`3'!"2(V00(
MZ,;(__^AA%$%",=$)`3M`0``B00DZ"'%__^)1>2#?>0`=#2#?>01="Z#?>3_
M="B+%811!0BAC%$%"(L`BTWDB4PD#(E4)`B)1"0$QP0DN-D$".ATR/__@\0P
M6UY=PU6)Y8/L*,<$)`````#H"\G__XL`B00DZ/'%__^)!"3H(<K__\<$)```
M``#H[<C__XL`B00DZ-/%___'1"04`````,=$)!#ZV`0(QT0D#/K8!`C'1"0(
MP\T$",=$)`0&V@0(B00DZ(/&___)PU6)Y8/D\(/L0(U%$(E$)`B-10R)1"0$
MC44(B00DZ&_(___'1"0(W)<$",=$)`3<EP0(QP0DK)D$".AW`@``QP0D````
M`.B'Q?__#[8`A,!U3>AKQ?__HX!1!0BA@%$%"(7`=0S'!"0!````Z('(__^A
M@%$%"(D$).@4QO__QP0D`````.@HR/__BP")!"3H#L7__XD$).AVQ___Q@``
MQP0D`````.@'R/__BP")!"3H[<3__XD$).@%R/__#[80@\H"B!#'!"0`````
MZ.''__^+`(D$).C'Q/__B00DZ-_'__\/MA"#R@&($(M%"(/`!;H`````B40D
M*(E4)"S?;"0HV>[>P=T%*-H$"-G)VNG?X)X/E\"$P'0,QP0D9%$%".C<QO__
MBT4(@\`%P>`"B00DZ.O&__^CC%$%"*&,404(BU4,BQ*)$*&,404(@\`$QP`;
MV@0(H8Q1!0B#P`C'`&#:!`C'!8A1!0@#````H8Q1!0B+%8A1!0C!X@(!T,<`
M'MH$"*&(404(@\`!HXA1!0C'1"0X`0```.LLBQ6,404(H8A1!0@#1"0X@^@!
MP>`"`<*+10R+3"0XP>$"`<B+`(D"@T0D.`&+10@Y1"0X?,NAC%$%"(M-"(L5
MB%$%"(T4$8/J`<'B`@'0QP``````BQ6,404(BTT(H8A1!0B-!`&-2/^A@%$%
M",=$)!``````B50D#(E,)`C'1"0$S]($"(D$).AJPO__B40D/(-\)#P`=1&A
M@%$%"(D$).@"P___B40D/*&`404(B00DZ`'%___'!"0`V`0(Z(W)__^%P'4P
MH811!0B%P'41QP0DT=<$".ATR?__HX11!0BAA%$%"(7`=`VAA%$%"(D$).CQ
M]/__H8!1!0B)!"3HY,'__^B?P___BT0D/,G#D)"0D)"0D)"0D)"0D%6)Y5/H
M,@```('#^WD``(/L$(N#3`$``(E$)`R+11")1"0(BT4,B40D!(M%"(D$).@W
MPO__@\006UW#BQPDPY!5B>5=PXUT)@"-O"<`````58GE5U93Z.#___^!PZEY
M``"#[`SHT\#__XV[\/[__XV#\/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$
M)`2+10B)!"3_E+/P_O__@\8!.?YRWH/$#%M>7UW#D)"0D)"058GE4X/L#(M%
M#.A\____@<-%>0``QP0D`P```(E$)`B+10B)1"0$Z%#!__^#Q`Q;7<.0D)"0
MD)"0D)"0D)"0D%6)Y5.#[`R+10SH//___X'#!7D``,<$)`,```")1"0(BT4(
MB40D!.@PPO__@\0,6UW#D)"0D)"0D)"0D)"0D)!5B>53@^P$H>1.!0B#^/]T
M$[OD3@4(9I"#ZP3_T(L#@_C_=?2#Q`1;7<.0D%6)Y5.#[`3H`````%N!PYQX
M``#H+,7__UE;R<,````````````````````````````````#`````0`"`'!E
M<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`+W!R;V,O<V5L
M9B]E>&4`+P`Z`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?4%)/1TY!
M344`+@`E<R5S)7,`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``
M4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`
M,0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``!,1%],24)2
M05)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`4$%42`!$64Q$7TQ)0E)!
M4EE?4$%42```0SI<5$5-4``O=&UP`%1-4$1)4@!414U01$E2`%1%35``5$U0
M`%5315(`55-%4DY!344`<&%R+0!365-414T`)7,E<R5S)7,`)7-C86-H92TE
M<R5S`"4P,G@`)7-T96UP+25U)7,`)7-T96UP+25U+25U)7,`+BX`)7,O)7,`
M05)'5@`8`'!E<FP`,```)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M
M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H
M("5I+@H`26YT97)N86QS.CI005(Z.D)/3U0`+64`+2T`````````````@/__
M_\]!`````````````````````'!A<BYP;```````````````````````````
M````````(R$O=7-R+V)I;B]P97)L"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@
M=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H
M:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE
M('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@
M("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A
M<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI
M<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R
M92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W
M<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES
M"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA
M="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I
M97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I
M=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H
M92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N
M"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U
M<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R
M92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@
M("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@
M,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@
M("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@
M("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@
M($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II
M9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?
M,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H
M,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!
M4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@
M("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE
M(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@
M(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M
M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN
M9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]?
M?2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T
M(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G
M;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68[
M"B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*
M("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E
M96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E
M96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@
M;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@
M("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N
M<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@
M("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P
M-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F
M:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%
M35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@
M("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@
M)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@
M("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@
M("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@
M*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@
M)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R
M97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!]
M(&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D
M9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L
M(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP
M9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*
M("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@
M(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I
M86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A3
M3&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE
M="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@
M("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G
M<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H
M97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ
M92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM[
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PH*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PH*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE
M8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?
M<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS
M=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R
M:69Y7W!A<@H@("`@*3L*"B`@("!M>2!`861D7W1O7VEN8SL*("`@('=H:6QE
M("A`05)'5BD@>PH@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@(&EF("@D,2!E<2`G22<I
M('L*("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@979A
M;"`B=7-E("0R(CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=!
M)RD@>PH@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@
M)&]U="`]("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)V(G
M*2!["B`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@)&)U;F1L
M92`]("=A;&PG.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G
M*2!["B`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@;W!E;B`D;&]G9F@L
M("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@
M("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@('T*"B`@("`@("`@<VAI
M9G0H0$%21U8I.PH*("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@
M("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@97AI=#L*("`@("`@("!]"B`@
M("!]"@H@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0H*(R!86%@@
M+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@
M;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@
M)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE
M(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O
M<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@
M("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@
M('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@
M("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@
M("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@
M("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*
M("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*
M("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@
M("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D
M97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@
M("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M
M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@
M("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L
M92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H
M*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I
M;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H
M*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@
M("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E
M)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("!I9B`H
M)$-O;F9I9WM?9&5L:6U](&5Q("=<7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC
M('T*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!2
M5"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y
M(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX
M+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E
M97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P
M;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H
M870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E
M;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M
M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D
M9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E
M=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@
M>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@
M(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@
M("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I
M9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@
M("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@
M("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@
M("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2![
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@
M(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@
M("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@
M;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM
M96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y
M("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@
M(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@
M("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@
M<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@
M?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I
M;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@
M3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI
M8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@
M("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@
M("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@
M("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX
M.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@
M("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF
M("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613
M:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T
M:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N
M86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@
M("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[
M)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@
M("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E
M<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER
M92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R
M<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X
M<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ
M5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,
M;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA
M;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R
M97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U
M:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@
M("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY
M;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z
M.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?
M=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@
M)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A
M=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY
M("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S
M(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@
M("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R
M;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@
M("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@
M('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@
M("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@
M("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6
M>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER
M+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@
M/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE
M(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N
M86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*
M("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@
M:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E
M='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R
M;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P
M<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@
M("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@
M("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@
M("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@
M("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@
M("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@
M?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@
M/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!8
M6%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@
M("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O
M;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@
M("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?
M0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@
M("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@
M:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@
M("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*
M"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE
M(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M
M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,#(*"E]?14Y$7U\*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````L@(```$```"]`@```0``
M`,<"```!````%@,```$```!)!```#````"R7!`@-````3-<$"`0```!H@00(
M]?[_;\"$!`@%````2(T$"`8````8A@0("@```-T%```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```+24!`@1````G)0$"!(`
M```8````$P````@```#^__]O#)0$"/___V\"````\/__;R:3!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````<I<$"(*7!`B2EP0(HI<$"+*7!`C"EP0(TI<$".*7!`CR
MEP0(`I@$"!*8!`@BF`0(,I@$"$*8!`A2F`0(8I@$"'*8!`B"F`0(DI@$"**8
M!`BRF`0(PI@$"-*8!`CBF`0(\I@$"`*9!`@2F00((ID$"#*9!`A"F00(4ID$
M"&*9!`ARF00(@ID$")*9!`BBF00(LID$",*9!`C2F00(XID$"/*9!`@"F@0(
M$IH$""*:!`@RF@0(0IH$"%*:!`ABF@0(<IH$"(*:!`B2F@0(HIH$"+*:!`C"
MF@0(TIH$".*:!`CRF@0(`IL$"!*;!`@BFP0(,IL$"$*;!`A2FP0(8IL$"'*;
M!`B"FP0(DIL$"**;!`BRFP0(PIL$"-*;!`CBFP0(\IL$"`*<!`@2G`0((IP$
M"#*<!`A"G`0(4IP$"```````````O=<$"+_7!`C_____0-H$"&U9````1T-#
M.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N-"XP+3!U
M8G5N='4V*2`T+C0N,```1T-#.B`H56)U;G1U(#0N-"XP+3!U8G5N='4V*2`T
M+C0N,```1T-#.B`H56)U;G1U(#0N-"XP+3!U8G5N='4V*2`T+C0N,```1T-#
M.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+3AU
M8G5N='4R*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T
M+C,N,P``1T-#.B`H56)U;G1U(#0N-"XP+3!U8G5N='4V*2`T+C0N,```1T-#
M.B`H56)U;G1U(#0N,RXS+3AU8G5N='4R*2`T+C,N,P``+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````"P````$````"````-($$"#0!```3```````````````!````````
M`!,````'`````@```$B!!`A(`0``(```````````````!``````````E````
M!0````(```!H@00(:`$``%@#```%``````````0````$````(0```/;__V\"
M````P(0$",`$``!8`0``!0`````````$````!````"L````+`````@```!B&
M!`@8!@``,`<```8````!````!````!`````S`````P````(```!(C00(2`T`
M`-T%``````````````$`````````.P```/___V\"````)I,$""83``#F````
M!0`````````"`````@```$@```#^__]O`@````R4!`@,%```D`````8````"
M````!`````````!7````"0````(```"<E`0(G!0``!@````%``````````0`
M```(````8`````D````"````M)0$"+04``!X`@``!0````P````$````"```
M`&D````!````!@```"R7!`@L%P``,```````````````!`````````!D````
M`0````8```!<EP0(7!<````%``````````````0````$````;P````$````&
M````8)P$"&`<``#L.@`````````````0`````````'4````!````!@```$S7
M!`A,5P``'```````````````!`````````![`````0````(```"`UP0(@%<`
M`$Y<`````````````"``````````@P````$````"````T#,%"-"S```$````
M```````````$`````````(T````!`````P```.1.!0CDO@``"```````````
M````!`````````"4`````0````,```#L3@4([+X```@```````````````0`
M````````FP````$````#````]$X%"/2^```$```````````````$````````
M`*`````&`````P```/A.!0CXO@``^`````8`````````!`````@```"I````
M`0````,```#P3P4(\+\```0```````````````0````$````K@````$````#
M````]$\%"/2_``!(`0`````````````$````!````+<````!`````P```#Q1
M!0@\P0``'```````````````!`````````"]````"`````,```!@404(6,$`
M`$00`````````````"``````````P@````$``````````````%C!``",`0``
M```````````!``````````$````#``````````````#DP@``RP``````````
+`````0``````````
